@@ -217,7 +217,12 @@ def __check_weave():
     Following simple snippet checks compilation of the basic code using
     weave
     """
-    from scipy import weave
+    try:
+        from scipy import weave
+    except OSError, e:
+        raise ImportError(
+            "Weave cannot be used due to failure to import because of %s"
+            % e)
     from scipy.weave import converters, build_tools
     import numpy as np
     # to shut weave up
@@ -449,11 +454,22 @@ def __check_rpy2():
     # doctests
     r.library = _R_library
 
+def __check_liblapack_so():
+    """Check either we could load liblapack.so library via ctypes
+    """
+    from ctypes import cdll
+    try:
+        lapacklib = cdll.LoadLibrary('liblapack.so')
+    except OSError, e:
+        # reraise with exception type we catch/handle while testing externals
+        raise RuntimeError("Failed to import liblapack.so: %s" % e)
+
 # contains list of available (optional) external classifier extensions
 _KNOWN = {'libsvm':'import mvpa2.clfs.libsvmc._svm as __; x=__.seq_to_svm_node',
           'libsvm verbosity control':'__check_libsvm_verbosity_control();',
           'nibabel':'__assign_nibabel_version()',
           'ctypes':'import ctypes as __',
+          'liblapack.so': "__check_liblapack_so()",
           'shogun':'__assign_shogun_version()',
           'shogun.krr': '__assign_shogun_version(); import shogun.Regression as __; x=__.KRR',
           'shogun.mpd': '__assign_shogun_version(); import shogun.Classifier as __; x=__.MPDSVM',
@@ -478,6 +494,8 @@ _KNOWN = {'libsvm':'import mvpa2.clfs.libsvmc._svm as __; x=__.seq_to_svm_node',
                   "import rpy2.robjects; rpy2.robjects.r.library('elasticnet')",
           'glmnet': "exists('rpy2', raise_='always'); " \
                   "import rpy2.robjects; rpy2.robjects.r.library('glmnet')",
+          'cran-energy': "exists('rpy2', raise_='always'); " \
+                  "import rpy2.robjects; rpy2.robjects.r.library('energy')",
           'matplotlib': "__assign_matplotlib_version()",
           'pylab': "__check_pylab()",
           'pylab plottable': "__check_pylab_plottable()",
@@ -505,6 +523,7 @@ _KNOWN = {'libsvm':'import mvpa2.clfs.libsvmc._svm as __; x=__.seq_to_svm_node',
           'h5py': "import h5py as __",
           'nipy': "__assign_nipy_version()",
           'nipy.neurospin': "__check_nipy_neurospin()",
+          'statsmodels': 'import statsmodels.api as __',
           }
 
 
@@ -648,7 +667,7 @@ versions._KNOWN.update({
 
 
 ##REF: Name was automagically refactored
-def test_all_dependencies(force=False, verbosity=1):
+def check_all_dependencies(force=False, verbosity=1):
     """
     Test for all known dependencies.
 
@@ -670,4 +689,3 @@ def test_all_dependencies(force=False, verbosity=1):
                      % [ k[5:] for k in cfg.options('externals')
                             if k.startswith('have') \
                             and cfg.getboolean('externals', k) == True ])
-
