@@ -44,7 +44,8 @@ from textwrap import TextWrapper
 # Although not used here -- included into interface
 from mvpa2.misc.exceptions import UnknownStateError
 from mvpa2.base.attributes import IndexedCollectable, ConditionalAttribute
-from mvpa2.base.dochelpers import enhanced_doc_string, borrowdoc, _repr_attrs
+from mvpa2.base.dochelpers import enhanced_doc_string, borrowdoc, _repr_attrs, \
+     get_docstring_split
 
 from mvpa2.base import externals
 # XXX local rename is due but later on
@@ -850,11 +851,17 @@ class ClassWithCollections(object):
                 else:
                     known_params = reduce(
                        lambda x,y:x+y,
-                       [x.keys() for x in collections.itervalues()], [])
-                    raise TypeError, \
-                          "Unexpected keyword argument %s=%s for %s." \
-                           % (arg, argument, self) \
-                          + " Valid parameters are %s" % known_params
+                        [x.keys()
+                         for x in collections.itervalues()
+                         if not isinstance(x, ConditionalAttributesCollection)
+                         ], [])
+                    _, kwargs_list, _ = get_docstring_split(self.__init__)
+                    known_params = sorted(known_params
+                                          + [x[0] for x in kwargs_list])
+                    raise TypeError(
+                        "Unexpected keyword argument %s=%s for %s."
+                        % (arg, argument, self)
+                        + "\n\tValid parameters are: %s" % ', '.join(known_params))
 
             ## Initialize other base classes
             ##  commented out since it seems to be of no use for now
@@ -1018,146 +1025,3 @@ class ClassWithCollections(object):
 
     descr = property(lambda self: self.__descr,
                      doc="Description of the object if any")
-
-
-
-class Harvestable(ClassWithCollections):
-    """Classes inherited from this class intend to collect attributes
-    within internal processing.
-
-    Subclassing Harvestable we gain ability to collect any internal
-    data from the processing which is especially important if an
-    object performs something in loop and discards some intermidiate
-    possibly interesting results (like in case of
-    CrossValidatedTransferError and ca of the trained classifier
-    or TransferError).
-
-    """
-
-    harvested = ConditionalAttribute(enabled=False, doc=
-       """Store specified attributes of classifiers at each split""")
-
-    _KNOWN_COPY_METHODS = [ None, 'copy', 'deepcopy' ]
-
-
-    def __init__(self, harvest_attribs=None, copy_attribs='copy', **kwargs):
-        """Initialize state of harvestable
-
-        Parameters
-        harvest_attribs : list of (str or dict)
-          What attributes of call to store and return within
-          harvested conditional attribute. If an item is a dictionary,
-          following keys are used ['name', 'copy'].
-        copy_attribs : None or str, optional
-          Default copying. If None -- no copying, 'copy'
-          - shallow copying, 'deepcopy' -- deepcopying.
-
-        """
-        ClassWithCollections.__init__(self, **kwargs)
-
-        self.__attribs = harvest_attribs
-        self.__copy_attribs = copy_attribs
-
-        self._set_attribs(harvest_attribs)
-
-
-    def _set_attribs(self, attribs):
-        """Set attributes to harvest
-
-        Each attribute in self.__attribs must have following fields
-         - name : functional (or arbitrary if 'obj' or 'attr' is set)
-                  description of the thing to harvest,
-                  e.g. 'transerror.clf.training_time'
-         - obj : name of the object to harvest from (if empty,
-                 'self' is assumed),
-                 e.g 'transerror'
-         - attr : attribute of 'obj' to harvest,
-                 e.g. 'clf.training_time'
-         - copy : None, 'copy' or 'deepcopy' - way to copy attribute
-        """
-        if attribs:
-            # force the state
-            self.ca.enable('harvested')
-            self.__attribs = []
-            for i, attrib in enumerate(attribs):
-                if isinstance(attrib, dict):
-                    if not 'name' in attrib:
-                        raise ValueError, \
-                              "Harvestable: attribute must be a string or " + \
-                              "a dictionary with 'name'"
-                else:
-                    attrib = {'name': attrib}
-
-                # assign default method to copy
-                if not 'copy' in attrib:
-                    attrib['copy'] = self.__copy_attribs
-
-                # check copy method
-                if not attrib['copy'] in self._KNOWN_COPY_METHODS:
-                    raise ValueError, "Unknown method %s. Known are %s" % \
-                          (attrib['copy'], self._KNOWN_COPY_METHODS)
-
-                if not ('obj' in attrib or 'attr' in attrib):
-                    # Process the item to harvest
-                    # split into obj, attr. If obj is empty, then assume self
-                    split = attrib['name'].split('.', 1)
-                    if len(split)==1:
-                        obj, attr = split[0], None
-                    else:
-                        obj, attr = split
-                    attrib.update({'obj':obj, 'attr':attr})
-
-                if attrib['obj'] == '':
-                    attrib['obj'] = 'self'
-
-                # TODO: may be enabling of the ca??
-
-                self.__attribs.append(attrib)     # place value back
-        else:
-            # just to make sure it is not None or 0
-            self.__attribs = []
-
-
-    def _harvest(self, vars):
-        """The harvesting function: must obtain dictionary of variables
-        from the caller.
-
-        Parameters
-        ----------
-        vars : dict
-          Dictionary of available data. Most often locals() could be
-          passed as `vars`. Mention that desired to be harvested
-          private attributes better be bound locally to some variable
-
-        Returns
-        -------
-        nothing
-        """
-
-        if not self.ca.is_enabled('harvested') or len(self.__attribs)==0:
-            return
-
-        if not self.ca.is_set('harvested'):
-            self.ca.harvested = dict([(a['name'], [])
-                                        for a in self.__attribs])
-
-        for attrib in self.__attribs:
-            attrv = vars[attrib['obj']]
-
-            # access particular attribute if needed
-            if not attrib['attr'] is None:
-                attrv = eval('attrv.%s' % attrib['attr'])
-
-            # copy the value if needed
-            attrv = {'copy':copy.copy,
-                     'deepcopy':copy.deepcopy,
-                     None:lambda x:x}[attrib['copy']](attrv)
-
-            self.ca.harvested[attrib['name']].append(attrv)
-
-
-    harvest_attribs = property(fget=lambda self:self.__attribs,
-                               fset=_set_attribs)
-
-
-
