@@ -12,6 +12,7 @@ import numpy as np
 from numpy import array
 import operator
 import sys
+import itertools
 
 from mvpa2.base import warning
 from mvpa2.base.dochelpers import borrowkwargs, borrowdoc, _repr_attrs, _repr
@@ -396,7 +397,6 @@ class IndexQueryEngine(QueryEngine):
     - repr
     """
 
-    @borrowkwargs(QueryEngine, '__init__')
     def __init__(self, sorted=True, **kwargs):
         """
         Parameters
@@ -573,7 +573,7 @@ class CachedQueryEngine(QueryEngineInterface):
     def __repr__(self, prefixes=[]):
         return super(CachedQueryEngine, self).__repr__(
             prefixes=prefixes
-            + _repr_attrs(self, ['qe']))
+            + _repr_attrs(self, ['queryengine']))
 
 
     def train(self, dataset):
@@ -618,10 +618,113 @@ class CachedQueryEngine(QueryEngineInterface):
 
     @borrowdoc(QueryEngineInterface)
     def query(self, **kwargs):
-        k = idhash_(kwargs.items())
+        def to_hashable(x):
+            """Convert x to something which dict wouldn't mind"""
+            import operator
+            try:
+                # silly attempt
+                d = {x: None}
+                return x
+            except TypeError:
+                pass
+
+            if isinstance(x, dict):
+                # keys are already hashable
+                # and sort for deterministic order
+                return tuple((k, to_hashable(v))
+                             for (k, v) in sorted(x.iteritems()))
+            elif operator.isSequenceType(x):
+                return tuple(i for i in x)
+            elif np.isscalar(x):
+                return x
+            return x   # and then wait for the report for it to be added
+
+        # idhash_ is somewhat inappropriate since also relies on id
+        # (which we should allow to differ) but ATM failing to hash
+        # ndarrays etc
+        # k = idhash_(kwargs.items())
+
+        # So let's use verbose version of the beastie (could have been
+        # also as simple as __repr__ but afraid that order could be
+        # changing etc).  This simple function should be sufficient
+        # for our typical use, otherwise we might like to use hashing
+        # facilities provided by joblib but for paranoid we would
+        # still need to store actual values to resolve collisions
+        # which would boil down to the same scenario
+        k = to_hashable(kwargs)
         v = self._lookup.get(k, None)
         if v is None:
             self._lookup[k] = v = self._queryengine.query(**kwargs)
         return v
 
     queryengine = property(fget=lambda self: self._queryengine)
+
+
+
+def scatter_neighborhoods(neighbor_gen, coords, deterministic=False):
+    """Scatter neighborhoods over a coordinate list.
+
+    Neighborhood seeds (or centers) are placed on coordinates drawn from a
+    provided list so that no seed is part of any other neighborhood. Depending
+    on the actual shape and size of the neighborhoods, their elements can be
+    overlapping, only the seeds (or centers) are guaranteed to be
+    non-overlapping with any other neighborhood. This can be used to perform
+    sparse sampling of a given space.
+
+    Parameters
+    ==========
+
+    neighbor_gen : neighborhood generator
+      Callable that return a list of neighborhood element coordinates, when
+      called with a seed coordinate (cf. Sphere)
+    coords : list
+      List of candidate corrdinates that can serve as neighborhood seeds or
+      elements.
+    deterministic : bool
+      If true, performs seed placement using an OrderedDict (available in
+      Python 2.7 or later) to guarantee deterministic placement of neighborhood
+      seeds in consecutive runs with identical input arguments.
+
+    Returns
+    =======
+    coordinates, indices
+      Two lists are returned. The first list contains the choosen seed
+      coordinates (a subset of the input coordinates), the second list
+      contains the indices of the respective seeds coordinates in the input
+      coordinate list. If particular coordinates are present multiple times
+      the index list will contain all indices corresponding to these
+      coordinates.
+    """
+    hasher = dict
+    if deterministic:
+        from collections import OrderedDict
+        hasher = OrderedDict
+
+    # put coordinates into a dict for fast lookup
+    try:
+        # quick test to check whether the given coords are hashable. If not,
+        # this test avoids a potentially long list zipping
+        _ = {coords[0]: None}
+        lookup = hasher()
+        _ = [lookup.setdefault(c, list()).append(i) for i, c in enumerate(coords)]
+    except TypeError:
+        # maybe coords not hashable?
+        lookup = hasher()
+        _ = [lookup.setdefault(tuple(c), list()).append(i) for i, c in enumerate(coords)]
+
+    seeds = []
+    while len(lookup):
+        # get any remaining coordinate
+        # with OrderedDict popitem will return the last inserted item by default
+        seed, idx = lookup.popitem()
+        # remove all coordinates in the neighborhood
+        _ = [lookup.pop(c, None) for c in neighbor_gen(seed)]
+        # store seed
+        seeds.append((seed, idx))
+    # unzip coords and idx again
+    coords, idx = zip(*seeds)
+    # we need a flat idx list
+    # yoh: sum trick replaced list(itertools.chain.from_iterable(idx))
+    #      which is not python2.5-compatible
+    idx = sum(idx, [])
+    return coords, idx
