@@ -8,7 +8,7 @@
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Unit tests for generators."""
 
-
+import itertools
 import numpy as np
 
 from mvpa2.testing.tools import ok_, assert_array_equal, assert_true, \
@@ -213,12 +213,49 @@ def test_sifter():
     ds = Dataset(samples=np.arange(8).reshape((4,2)),
                  sa={'chunks':   [ 0 ,  1 ,  2 ,  3 ],
                      'targets':  ['c', 'c', 'p', 'p']})
-    par = ChainNode([NFoldPartitioner(cvtype=2, attr='chunks'),
+    for sift_targets_definition in (['c', 'p'],
+                                    dict(uvalues=['c', 'p'])):
+        par = ChainNode([NFoldPartitioner(cvtype=2, attr='chunks'),
+                         Sifter([('partitions', 2),
+                                 ('targets', sift_targets_definition)])
+                         ])
+        dss = list(par.generate(ds))
+        assert_equal(len(dss), 4)
+        for ds_ in dss:
+            testing = ds[ds_.sa.partitions == 2]
+            assert_array_equal(np.unique(testing.sa.targets), ['c', 'p'])
+            # and we still have both targets  present in training
+            training = ds[ds_.sa.partitions == 1]
+            assert_array_equal(np.unique(training.sa.targets), ['c', 'p'])
+
+def test_sifter_with_balancing():
+    # extended previous test which was already
+    # "... somewhat duplicating the doctest"
+    ds = Dataset(samples=np.arange(12).reshape((-1, 2)),
+                 sa={'chunks':   [ 0 ,  1 ,  2 ,  3 ,  4,   5 ],
+                     'targets':  ['c', 'c', 'c', 'p', 'p', 'p']})
+
+    # Without sifter -- just to assure that we do get all of them
+    # i.e. 6*5*4*3/(4!) = 15
+    par = ChainNode([NFoldPartitioner(cvtype=4, attr='chunks')])
+    assert_equal(len(list(par.generate(ds))), 15)
+
+    # so we will take 4 chunks out of available 7, but would care only
+    # about those partitions where we have balanced number of 'c' and 'p'
+    # entries
+    assert_raises(ValueError,
+                  lambda x: list(Sifter([('targets', dict(wrong=1))]).generate(x)),
+                  ds)
+
+    par = ChainNode([NFoldPartitioner(cvtype=4, attr='chunks'),
                      Sifter([('partitions', 2),
-                             ('targets', ['c', 'p'])])
+                             ('targets',
+                              dict(uvalues=['c', 'p'],
+                                   balanced=True))])
                      ])
     dss = list(par.generate(ds))
-    assert_equal(len(dss), 4)
+    # print [ x[x.sa.partitions==2].sa.targets for x in dss ]
+    assert_equal(len(dss), 9)
     for ds_ in dss:
         testing = ds[ds_.sa.partitions == 2]
         assert_array_equal(np.unique(testing.sa.targets), ['c', 'p'])
@@ -248,3 +285,38 @@ def test_exclude_targets_combinations():
         comb_chunks.append(comb + tuple(np.unique(teds.chunks)))
     assert_equal(len(set(combs)), 6)         # just 6 possible combinations of 2 out of 4
     assert_equal(len(set(comb_chunks)), 3*6) # all unique
+
+
+def test_exclude_targets_combinations_subjectchunks():
+    partitioner = ChainNode([NFoldPartitioner(attr='subjects'),
+                             ExcludeTargetsCombinationsPartitioner(
+                                 k=1,
+                                 targets_attr='chunks',
+                                 space='partitions')],
+                            space='partitions')
+    # targets do not need even to be defined!
+    ds = Dataset(np.arange(18).reshape(9, 2),
+                 sa={'chunks': np.arange(9) // 3,
+                     'subjects': np.arange(9) % 3})
+    dss = list(partitioner.generate(ds))
+    assert_equal(len(dss), 9)
+
+    testing_subjs, testing_chunks = [], []
+    for ds_ in dss:
+        testing_partition = ds_.sa.partitions == 2
+        training_partition = ds_.sa.partitions == 1
+        # must be scalars -- so implicit test here
+        # if not -- would be error
+        testing_subj = np.asscalar(np.unique(ds_.sa.subjects[testing_partition]))
+        testing_subjs.append(testing_subj)
+        testing_chunk = np.asscalar(np.unique(ds_.sa.chunks[testing_partition]))
+        testing_chunks.append(testing_chunk)
+        # and those must not appear for training
+        ok_(not testing_subj in ds_.sa.subjects[training_partition])
+        ok_(not testing_chunk in ds_.sa.chunks[training_partition])
+    # and we should have gone through all chunks/subjs pairs
+    testing_pairs = set(zip(testing_subjs, testing_chunks))
+    assert_equal(len(testing_pairs), 9)
+    # yoh: equivalent to set(itertools.product(range(3), range(3))))
+    #      but .product is N/A for python2.5
+    assert_equal(testing_pairs, set(zip(*np.where(np.ones((3,3))))))
