@@ -20,7 +20,7 @@ from mvpa2.generators.splitters import Splitter
 from mvpa2.generators.partition import *
 
 from mvpa2.testing.tools import ok_, assert_array_equal, assert_true, \
-        assert_false, assert_equal, reseed_rng
+        assert_false, assert_equal, assert_not_equal, reseed_rng
 
 class SplitterTests(unittest.TestCase):
 
@@ -30,6 +30,22 @@ class SplitterTests(unittest.TestCase):
                             targets=[ i%4 for i in range(100) ],
                             chunks=[ i/10 for i in range(100)])
 
+    def test_splitattr_deprecation(self):
+        # Just a smoke test -- remove for 2.1 release
+        nfs = NFoldPartitioner()
+        _ = nfs.splitattr
+
+    def test_reprs(self):
+        # very very basic test to see that there is no errors in reprs
+        # of partitioners
+        import mvpa2.generators.partition as mgp
+        for sclass in (x for x in dir(mgp) if x.endswith('Partitioner')):
+            args = (1,)
+            if sclass == 'ExcludeTargetsCombinationsPartitioner':
+                args += (1,1)
+            pclass = getattr(mgp, sclass)
+            r = repr(pclass(*args))
+            assert_false('ERROR' in r)
 
     def test_simplest_cv_pat_gen(self):
         # create the generator
@@ -170,6 +186,55 @@ class SplitterTests(unittest.TestCase):
         s20 = NGroupPartitioner(20)
         self.assertRaises(ValueError,splitcall,s20,self.data)
 
+    @reseed_rng()
+    def test_nfold_random_counted_selection_partitioner(self):
+        # Lets get somewhat extensive but complete one and see if
+        # everything is legit. 0.5 must correspond to 50%, in our case
+        # 5 out of 10 unique chunks
+        split_partitions = [
+            tuple(x.sa.partitions)
+            for x in NFoldPartitioner(0.5).generate(self.data)]
+        # 252 is # of combinations of 5 from 10
+        assert_equal(len(split_partitions), 252)
+
+        # verify that all of them are unique
+        assert_equal(len(set(split_partitions)), 252)
+
+        # now let's limit our query
+        kwargs = dict(count=10, selection_strategy='random')
+        split10_partitions = [
+            tuple(x.sa.partitions)
+            for x in NFoldPartitioner(5, **kwargs).generate(self.data)]
+        split10_partitions_ = [
+            tuple(x.sa.partitions)
+            for x in NFoldPartitioner(0.5, **kwargs).generate(self.data)]
+        # to make sure that I deal with sets of tuples correctly:
+        assert_equal(len(set(split10_partitions)), 10)
+        assert_equal(len(split10_partitions), 10)
+        assert_equal(len(split10_partitions_), 10)
+        # and they must differ (same ones are possible but very very unlikely)
+        assert_not_equal(split10_partitions, split10_partitions_)
+        # but every one of them must be within known exhaustive set
+        assert_equal(set(split_partitions).intersection(split10_partitions),
+                     set(split10_partitions))
+        assert_equal(set(split_partitions).intersection(split10_partitions_),
+                     set(split10_partitions_))
+
+    @reseed_rng()
+    def test_nfold_random_counted_selection_partitioner_huge(self):
+        # Just test that it completes in a reasonable time and does
+        # not blow up as if would do if it was not limited by count
+        kwargs = dict(count=10)
+        ds = dataset_wizard(np.arange(1000).reshape((-1, 1)),
+                            targets=range(1000),
+                            chunks=range(500)*2)
+        split_partitions_random = [
+            tuple(x.sa.partitions)
+            for x in NFoldPartitioner(100,  selection_strategy='random',
+                                      **kwargs).generate(ds)]
+        assert_equal(len(split_partitions_random), 10) # we get just 10
+
+
     def test_custom_split(self):
         #simulate half splitter
         hs = CustomPartitioner([(None,[0,1,2,3,4]),(None,[5,6,7,8,9])])
